From: "Daniel Marjamäki" <daniel.marjamaki@comhem.se>
To: kernel-janitors@vger.kernel.org
Subject: [KJ] use kzalloc instead of kcalloc(1, ...) in /kernel/kprobes.c
Date: Tue, 29 Nov 2005 06:02:13 +0000 [thread overview]
Message-ID: <438BEEE5.6060208@comhem.se> (raw)
Hello!
I believe you are patching against the wrong version, my friend.
I applied the changes manually and then made a new patch:
--- a/kernel/kprobes.c 2005-11-28 07:17:58.000000000 +0100
+++ b/kernel/kprobes.c 2005-11-29 06:29:15.000000000 +0100
@@ -408,7 +408,7 @@ static inline void add_aggr_kprobe(struc
/*
* This is the second or subsequent kprobe at the address - handle
* the intricacies
* TODO: Move kcalloc outside the spin_lock
*/
static int __kprobes register_aggr_kprobe(struct kprobe *old_p,
struct kprobe *p)
@@ -420,7 +420,7 @@ static int __kprobes register_aggr_kprob
copy_kprobe(old_p, p);
ret = add_new_kprobe(old_p, p);
} else {
- ap = kcalloc(1, sizeof(struct kprobe), GFP_ATOMIC);
+ ap = kzalloc(sizeof(struct kprobe), GFP_ATOMIC);
if (!ap)
return -ENOMEM;
add_aggr_kprobe(ap, old_p);
The line numbers are a little different here, compared to your patch.
Regards,
Daniel Marjamäki
_______________________________________________
Kernel-janitors mailing list
Kernel-janitors@lists.osdl.org
https://lists.osdl.org/mailman/listinfo/kernel-janitors
reply other threads:[~2005-11-29 6:02 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=438BEEE5.6060208@comhem.se \
--to=daniel.marjamaki@comhem.se \
--cc=kernel-janitors@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -408,7 +408,7 @@ static inline void add_aggr_kprobe(struc
* This is the second or subsequent kprobe at the address - handle
* the intricacies
- * TODO: Move kcalloc outside the spin_lock
+ * TODO: Move kzalloc outside the spin_lock
*/
static int __kprobes register_aggr_kprobe(struct kprobe *old_p,
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.